@@ -2,6 +2,7 @@
 //! Border is a library for reinforcement learning (RL).
 pub mod core;
 pub mod error;
+mod shape;
 pub use crate::core::{
     base::{Act, Agent, Env, Obs, Policy, Step, Info},
     trainer::{Trainer, TrainerBuilder},
@@ -9,3 +10,4 @@ pub use crate::core::{
     util,
     record,
 };
+pub use shape::Shape;
